<?php

namespace Event\Event\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Event\Event\Http\Requests\PrizeRequest;
use Event\Event\Models\Prize;

/**
 * Admin web controller class.
 */
class PrizeWorkflowController extends BaseController
{

    /**
     * Workflow controller function for prize.
     *
     * @param Model   $prize
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(PrizeRequest $request, Prize $prize, $step)
    {

        try {

            $prize->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('event::prize.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/prize/prize/' . $prize->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/prize/prize/' . $prize->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for prize.
     *
     * @param Model   $prize
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Prize $prize, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $prize->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('event::prize.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('event::admin.prize.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('event::admin.prize.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('event::admin.prize.message', $data)->render();

        }

    }
}
