<?php

namespace Event\Event\Policies;

use Litepie\User\Contracts\UserPolicy;
use Event\Event\Models\Prize;

class PrizePolicy
{

    /**
     * Determine if the given user can view the prize.
     *
     * @param UserPolicy $user
     * @param Prize $prize
     *
     * @return bool
     */
    public function view(UserPolicy $user, Prize $prize)
    {
        if ($user->canDo('event.prize.view') && $user->isAdmin()) {
            return true;
        }

        return $prize->user_id == user_id() && $prize->user_type == user_type();
    }

    /**
     * Determine if the given user can create a prize.
     *
     * @param UserPolicy $user
     * @param Prize $prize
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('event.prize.create');
    }

    /**
     * Determine if the given user can update the given prize.
     *
     * @param UserPolicy $user
     * @param Prize $prize
     *
     * @return bool
     */
    public function update(UserPolicy $user, Prize $prize)
    {
        if ($user->canDo('event.prize.edit') && $user->isAdmin()) {
            return true;
        }

        return $prize->user_id == user_id() && $prize->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given prize.
     *
     * @param UserPolicy $user
     * @param Prize $prize
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Prize $prize)
    {
        return $prize->user_id == user_id() && $prize->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given prize.
     *
     * @param UserPolicy $user
     * @param Prize $prize
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Prize $prize)
    {
        if ($user->canDo('event.prize.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given prize.
     *
     * @param UserPolicy $user
     * @param Prize $prize
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Prize $prize)
    {
        if ($user->canDo('event.prize.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
