<?php

namespace Event\Event\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Event\Event\Models\Prize;

class PrizeAction
{
    /**
     * Perform the complete action.
     *
     * @param Prize $prize
     *
     * @return Prize
     */
    public function complete(Prize $prize)
    {
        try {
            $prize->status = 'complete';
            return $prize->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Prize $prize
     *
     * @return Prize
     */public function verify(Prize $prize)
    {
        try {
            $prize->status = 'verify';
            return $prize->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Prize $prize
     *
     * @return Prize
     */public function approve(Prize $prize)
    {
        try {
            $prize->status = 'approve';
            return $prize->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Prize $prize
     *
     * @return Prize
     */public function publish(Prize $prize)
    {
        try {
            $prize->status = 'publish';
            return $prize->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Prize $prize
     *
     * @return Prize
     */
    public function archive(Prize $prize)
    {
        try {
            $prize->status = 'archive';
            return $prize->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Prize $prize
     *
     * @return Prize
     */
    public function unpublish(Prize $prize)
    {
        try {
            $prize->status = 'unpublish';
            return $prize->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
